﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using HeuristicLab.PluginInfrastructure;

namespace HeuristicLab.DeploymentService.AdminClient {
  public partial class LocalPluginView : PluginView {
    private IPluginDescription plugin;

    public LocalPluginView() {
      InitializeComponent();
    }

    public LocalPluginView(IPluginDescription plugin) {
      InitializeComponent();
      this.plugin = plugin;
      UpdateControls();
    }

    public void UpdateControls() {
      nameTextBox.Text = plugin.Name;
      versionTextBox.Text = plugin.Version.ToString();
      contactTextBox.Text = CombineStrings(plugin.ContactName, plugin.ContactEmail);
      foreach (IPluginDescription dependency in plugin.Dependencies) {
        dependenciesListView.Items.Add(new ListViewItem(new string[] { dependency.Name, dependency.Version.ToString() }));
      }
      foreach (var file in plugin.Files) {
        filesListView.Items.Add(new ListViewItem(new string[] { file.Name, file.Type.ToString() }));
      }
      licenseButton.Enabled = !string.IsNullOrEmpty(plugin.LicenseText);
    }

    private string CombineStrings(string a, string b) {
      if (string.IsNullOrEmpty(a))
        // a is empty
        if (!string.IsNullOrEmpty(b)) return CombineStrings(b, string.Empty);
        else return string.Empty;
      // a is not empty
      else if (string.IsNullOrEmpty(b)) return a;
      // and b are not empty
      else return a + ", " + b;
    }

    private void licenseButton_Click(object sender, EventArgs e) {
      LicenseView view = new LicenseView(plugin.Name, plugin.Version.ToString(), plugin.LicenseText);
      view.Show();
    }
  }
}
